@@ -8,6 +8,14 @@
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef LINUX
+#ifdef FLOCK
+#include <sys/file.h>
+#endif
+#ifdef FCNTL
+#include <fcntl.h>
+#endif
+#endif
 #include "msdos.h"
 
 #define FULL_CYL
@@ -18,6 +26,7 @@ unsigned int num_clus;			/* total number of cluster */
 int num_fat;				/* the number of FAT tables */
 long disk_offset;			/* skip this many bytes */
 int fat_bits;				/* the FAT encoding scheme */
+static int lock_dev(int fd);
 
 extern int fd, fat_len, dir_len, dir_start, clus_size, dir_dirty, disk_dirty;
 extern int fat_error, disk_size;
