@@ -82,7 +82,11 @@ char *argv[];
 	 * with a null when it passes it to main()
 	 */
 	nargv = (char **) malloc((unsigned int) (argc + 1) * sizeof(*argv));
+#ifndef MERGED
 	nargv[0] = "mcopy";
+#else
+	nargv[0] = destination == MWRITE ? "mwrite" : "mread";
+#endif
 	for (i = 1; i < argc; i++)
 		nargv[i] = argv[i];
 	nargv[argc] = NULL;
