@@ -59,3 +59,31 @@ typedef void SIG_TYPE;
 #define strchr index
 #define strrchr rindex
 #endif /* BSD */
+
+#define FAT12 4086 /* max. number of clusters described by a 12 bit FAT */
+
+#ifdef MERGED
+#ifdef DEBIAN
+#define CFG_FILE "/etc/mtools.ref"
+#else
+#define CFG_FILE "/etc/mtools"
+#endif
+#else
+#define CFG_FILE NULL
+#endif
+
+#ifdef MERGED
+extern int fd;				/* the file descriptor for the device */
+extern int dir_start;			/* starting sector for directory */
+extern int dir_len;			/* length of directory (in sectors) */
+extern int dir_entries;			/* number of directory entries */
+extern int clus_size;			/* cluster size (in sectors) */
+extern char *mcwd;			/* the Current Working Directory */
+extern int fat_error;			/* FAT error detected? */
+#endif
+
+#ifdef DEBIAN
+#ifdef CHK_FAT_OPTION
+extern int chk_fat_flag;
+#endif
+#endif
